from test_module_2 import test_module_2
from test_module_1 import test_module_1

if __name__ == "__main__":

    if (test_module_2.cargiant_test()):
        print("-------Test_2 cargiant PASSED!")

    if (test_module_2.one_page_car_giant()):
        print("-------Test_2 one_page_car_giant PASSED!")

    if (test_module_1.big_motor_test()):
        print("-------Test_2 cargiant PASSED!")

    if (test_module_1.one_page_car_giant()):
        print("-------Test_2 one_page_car_giant PASSED!")